pub fn get<Opt: FromObject + Debug>(
name: &str,
opts: &OptionOpts,
) -> Option<Opt>Expand description
Gets a Vim option by name within the given [OptionOpts].
Errors are notified to Nvim via ytil_noxi::notify::error.
pub fn get<Opt: FromObject + Debug>(
name: &str,
opts: &OptionOpts,
) -> Option<Opt>Gets a Vim option by name within the given [OptionOpts].
Errors are notified to Nvim via ytil_noxi::notify::error.